@@ -4,8 +4,8 @@
 # Author          : Miao-Jane Lin <mjlin@cs.cornell.edu>
 # Created On      : Wed Apr 27 08:30:01 1994
 # Last Modified By: Ulrich Pfeifer
-# Last Modified On: Fri Jun 24 18:17:10 1994
-# Update Count    : 383
+# Last Modified On: Mon Dec 12 11:37:13 1994
+# Update Count    : 388
 # Status          : Unknown, Use with caution!
 # 
 
@@ -53,9 +53,6 @@
 # reverse of main
 # connect a server, send searchAPU, receive and interprete response
 #-------------------------------------------------------------------
-$AF_INET = 2;
-$SOCK_STREAM =	1;
-$sockaddr = 'S n a4 x8';
 
 sub client {
     local ($them, $database, $port, $queryType, $query) = @_;
@@ -64,21 +61,21 @@ sub client {
     $them = $defserver unless $them;
     $database = $serverdb unless $database;
 
-    &dprint("AF_INET=%d SOCK_STREAM=%d sockaddr=%s hostname=%s\n",
-            $AF_INET, $SOCK_STREAM, $sockaddr, $hostname);
+    &dprint("af_inet=%d sock_stream=%d sockaddr=%s hostname=%s\n",
+            $af_inet, $sock_stream, $sockaddr, $hostname);
     ($name,$aliases,$proto) = getprotobyname('tcp');
     ($name,$aliases,$type,$len,$thisaddr) =
 	gethostbyname($hostname);
     ($name,$aliases,$type,$len,$thataddr) = 
         gethostbyname($them);
 
-    $this = pack($sockaddr, $AF_INET, 0, $thisaddr);
+    $this = pack($sockaddr, $af_inet, 0, $thisaddr);
     &dprint("thisaddr=%d,this=%d\n", $thisaddr,$this);
-    $that = pack($sockaddr, $AF_INET, $port, $thataddr);
+    $that = pack($sockaddr, $af_inet, $port, $thataddr);
 
 # Make the socket filehandle.
 
-    if (socket(S, $AF_INET, $SOCK_STREAM, $proto='tcp')) { 
+    if (socket(S, $af_inet, $sock_stream, $proto='tcp')) { 
         &dprint("socket ok\n");
     }
     else {
@@ -147,7 +144,8 @@ sub add_headline {
     $connection = &encode("$server:$port");
 
     $documentID =~ s/4=[^;]*/4=$connection/ unless $server eq "$defserver";
-    
+    $documentID =~ s/\+/%2B/g;
+
     &dprint ("
 documentID      = $documentID 
 HeaderVersion   = $HeaderVersion 
@@ -163,12 +161,12 @@ originCity      = $originCity
 ");
     $documentID =~ s/\s/%20/g;                    # maybe we schuld encode all ?
     $edatabase = &encode($database);
-    if ($type eq "URL") {
-        ($url) = ($documentID =~ m/3=\d+%20\d+%20([^;]*)/);
-    } else {
+#    if ($type eq "URL") {
+#        ($url) = ($documentID =~ m/3=\d+%20\d+%20([^;]*)/);
+#    } else {
         $documentID =~ s/:/%3A/g;
         $url = "$edatabase/$type/$documentLength/$documentID;";
-    }
+#    }
     # global array @headlines *must* be deleted before next run of client
     push(@headlines, join('|', $score, $lines, $url, $headline));
 }
