@@ -183,7 +183,7 @@ $any_type = 'L1 a*';
 $bitsPerByte = 8;
 $maxBufSize = 29952; # just give some limit; refered from source code
 $defaultID = "TMC";
-$defaultName = "Ulrich Pfeifer <pfeifer@ls6.informatik.uni-dortmund.de";
+$defaultName = "Ulrich Pfeifer <pfeifer\@ls6.informatik.uni-dortmund.de";
 $defaultVersion = $revision;
 $diagnosticCodeSize = 3;
 $endOfRecord = 29; # 1D in hexadecimal
